@@ -20,10 +20,11 @@ class App:
 	# do we actually need the url? 
 	# TODO figure out how to allow people to specify the version of python to use
 	# TODO infer user id automatically
-	def __init__(self, app, user_id="shared"): # TODO change app to name
+	def __init__(self, app, user_id="shared", local=False): # TODO change app to name
 		# TODO sanitize the user id and app name
 		self.user_id = user_id # TODO once we have auth will no longer have this be shared
 		self.app = app
+		self.local = local
 
 		# create a build directory 
 		self.current_dir = os.getcwd()
@@ -51,7 +52,7 @@ class App:
 
 	def register_task(self, activity):
 		print("Registering task")
-		activity_server = ActivityServer(activity) # Q: this gets shut down?
+		activity_server = ActivityServer(activity, self.local) # Q: this gets shut down?
 		activity_server.start()
 		# start the activity server
 
